@@ -41,8 +41,6 @@
 
 #define KWAYLANDSERVER_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
-#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
-
 /* Take any defaults from group settings */
 #if !defined(KWAYLANDSERVER_NO_DEPRECATED) && !defined(KWAYLANDSERVER_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #  ifdef KF_NO_DEPRECATED
@@ -86,7 +84,7 @@
 #define KWAYLANDSERVER_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KWAYLANDSERVER_NO_DEPRECATED
-#  define KWAYLANDSERVER_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56800
+#  define KWAYLANDSERVER_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56a00
 #endif
 #ifdef KWAYLANDSERVER_NO_DEPRECATED_WARNINGS
 #  define KWAYLANDSERVER_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +94,7 @@
 #  ifdef KWAYLANDSERVER_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KWAYLANDSERVER_DEPRECATED_WARNINGS_SINCE KWAYLANDSERVER_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KWAYLANDSERVER_DEPRECATED_WARNINGS_SINCE 0x56800
+#    define KWAYLANDSERVER_DEPRECATED_WARNINGS_SINCE 0x56a00
 #  endif
 #endif
 
@@ -105,7 +103,7 @@
 #endif
 
 #ifdef KWAYLANDSERVER_DEPRECATED
-#  define KWAYLANDSERVER_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KWAYLANDSERVER_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define KWAYLANDSERVER_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KWAYLANDSERVER_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define KWAYLANDSERVER_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
